Index: src/utils/SkTextureCompressor_Blitter.h |
diff --git a/src/utils/SkTextureCompressor_Blitter.h b/src/utils/SkTextureCompressor_Blitter.h |
index e52237518f3b5840576739e7e6f3f124ed6769b4..0c259d692aa974831cb5118d8e15ba35d34d4709 100644 |
--- a/src/utils/SkTextureCompressor_Blitter.h |
+++ b/src/utils/SkTextureCompressor_Blitter.h |
@@ -366,10 +366,10 @@ public: |
} |
// If the blitter just sets a single value for each pixel, return the |
// bitmap it draws into, and assign value. If not, return NULL and ignore |
// the value parameter. |
const SkPixmap* justAnOpaqueColor(uint32_t* value) override { |
- return NULL; |
+ return nullptr; |
} |
/** |
@@ -366,10 +366,10 @@ public: |
} |
// If the blitter just sets a single value for each pixel, return the |
- // bitmap it draws into, and assign value. If not, return NULL and ignore |
+ // bitmap it draws into, and assign value. If not, return nullptr and ignore |
// the value parameter. |
const SkPixmap* justAnOpaqueColor(uint32_t* value) override { |